/* 
 * INTEL CONFIDENTIAL
 * Copyright © 2011 Intel 
 * Corporation All Rights Reserved.
 * 
 * The source code contained or described herein and all documents related to
 * the source code ("Material") are owned by Intel Corporation or its suppliers
 * or licensors. Title to the Material remains with Intel Corporation or its
 * suppliers and licensors. The Material contains trade secrets and proprietary
 * and confidential information of Intel or its suppliers and licensors. The
 * Material is protected by worldwide copyright and trade secret laws and
 * treaty provisions. No part of the Material may be used, copied, reproduced,
 * modified, published, uploaded, posted, transmitted, distributed, or
 * disclosed in any way without Intel’s prior express written permission.
 * 
 * No license under any patent, copyright, trade secret or other intellectual
 * property right is granted to or conferred upon you by disclosure or delivery
 * of the Materials, either expressly, by implication, inducement, estoppel or
 * otherwise. Any license under such intellectual property rights must be
 * express and approved by Intel in writing.
 * 
 * CREATED: 2011-06-01
 * UPDATED: 2011-07-27
 */
#pragma once

#include "ConfigurableElement.h"
#include "SubsystemPlugins.h"
#include <list>

class CSubsystemLibrary;

class CSystemClass : public CConfigurableElement
{
public:
    CSystemClass();
    virtual ~CSystemClass();

    // Called from parent before actual init
    bool loadSubsystems(string& strError, const CSubsystemPlugins* pSubsystemPlugins);
    // Subsystem factory
    const CSubsystemLibrary* getSubsystemLibrary() const;

    // Fill syncer-set with syncers from subsytems that need resync
    void checkForSubsystemsToResync(CSyncerSet& syncerSet);

    // base
    virtual bool init(string& strError);
    virtual string getKind() const;

    // From IXmlSource
    virtual void toXml(CXmlElement& xmlElement, CXmlSerializingContext& serializingContext) const;

private:
    CSystemClass(const CSystemClass&);
    CSystemClass& operator=(const CSystemClass&);
    // base
    virtual bool childrenAreDynamic() const;

    // Subsystem plugins
    bool getPluginFiles(const string& strPluginPath, list<string>& lstrPluginFiles) const;

    // Plugin symbol computation
    static string getPluginSymbol(const string& strPluginPath);

    // Plugin loading
    bool loadPlugins(list<string>& lstrPluginFiles, string& strError);

    // Subsystem factory
    CSubsystemLibrary* _pSubsystemLibrary;
};

